=============
API Reference
=============

cfn_pyplates
============

.. automodule:: cfn_pyplates

cfn_pyplates.cli
================

.. automodule:: cfn_pyplates.cli
    :members:

cfn_pyplates.core
=================

.. automodule:: cfn_pyplates.core
    :members:

cfn_pyplates.exceptions
=======================

.. automodule:: cfn_pyplates.exceptions
    :members:

cfn_pyplates.functions
======================

.. automodule:: cfn_pyplates.functions
    :members:

.. _cfn-conditions: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/conditions-section-structure.html
.. _cfn-deletionpolicy: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-deletionpolicy.html
.. _cfn-dependson: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-dependson.html
.. _cfn-ec2tags: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-tags.html
.. _cfn-functions: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference.html
.. _cfn-functions-conditions: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-conditions.html
.. _cfn-mappings: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/mappings-section-structure.html
.. _cfn-metadata: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-metadata.html
.. _cfn-outputs: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/outputs-section-structure.html
.. _cfn-parameters: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/parameters-section-structure.html
.. _cfn-properties: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/properties-section-structure.html
.. _cfn-resources: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/resources-section-structure.html
.. _cfn-resource-types: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-template-resource-type-ref.html
.. _cfn-template: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/template-structure.html
.. _cfn-updatepolicy: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-updatepolicy.html
